{ lib, pkgs, config, inputs, ... }: let
  flakePackage = flake: inputs.${flake}.packages.${pkgs.system}.default;
in rec {
  imports = [
    ../../templates/proxmox-lxc.nix
    ../../server.nix
    ../../features/dns-cache.nix
    ../../features/nginx.nix
    ../../features/telemetry/nginx.nix
    ./minio.nix
  ];

  networking.hostName = "static-sites";
  system.stateVersion = "24.05"; 
  nixpkgs.hostPlatform = "x86_64-linux";
  
  networking.firewall.allowedTCPPorts = [ 80 ];
  networking.firewall.allowedUDPPorts = [ 80 ];

  services.nginx = {
    recommendedBrotliSettings = true;
    recommendedGzipSettings = true;
    recommendedZstdSettings = true;    

    virtualHosts = let
      defaultConfig = {
        listen = [
          { addr = "0.0.0.0"; port = 80; }
          { addr = "[::]"; port = 80; }
        ];    
      };
      static = { src ? null, url ? null, rev ? null, aliases ? [] }: {
        serverAliases = aliases;

        root = if src != null then src else builtins.fetchGit { inherit url rev; };
      } // defaultConfig;
      placeholder = {
        locations."=/" = {
          root = pkgs.writeText "placeholder.html" "empty space -- this site is non-functional";
          extraConfig = ''
            default_type text/plain;
          '';
        };
      } // defaultConfig;
      minio = bucket: {
        locations."/" = {
          proxyPass = "http://127.0.0.1:9000/${bucket}/";
          recommendedProxySettings = true;
          extraConfig = ''
            proxy_intercept_errors on;

            # minio why so fingerprintable....
            proxy_hide_header x-amz-request-id;
            proxy_hide_header x-amz-bucket-region;
            proxy_hide_header x-amz-id-2;
            proxy_hide_header x-amz-meta-s3cmd-attrs;
            proxy_hide_header x-ratelimit-limit;
            proxy_hide_header x-ratelimit-remaining;
            proxy_hide_header x-minio-deployment-id;
            proxy_hide_header strict-transport-security;
            proxy_hide_header x-firefox-spdy;
            proxy_hide_header x-xss-protection;
            proxy_hide_header x-content-type-options;
            proxy_hide_header vary;

            # prevent minio fingerprinting back...
            proxy_set_header user-agent "";
            proxy_method GET;

            rewrite (.*)/$ $1/index.html;
          '';
        };
      } // defaultConfig;
    in rec {
      "blood.pet" = minio "blood.pet";                    
      "doll.repair" = minio "doll.repair";
      "foxxolay.com" = minio "foxxolay.com";
      "kitsu.love" = minio "kitsu.love";
      "mekanoe.com" = minio "noe.sh";
      "noe.sh" = minio "noe.sh";
      #TODO: ;w; its brokenn
      # // {
      #   # serverAliases = [ "mekanoe.com" ];
      #   locations."=/" = {
      #     extraConfig = ''
      #       if ($http_user_agent ~ curl/) {
      #         rewrite ^ /noe.sh/noe.sh;
      #       }
      #     '';
      #   };
      # };

      # "3d.noe.sh" = static { src = flakePackage "3d-noe-sh"; aliases = [ "art.mekanoe.com" ]; };
    };
  };
}
